@@ -1,11 +1,15 @@
 # -*- coding: utf-8 -*-
+from datetime import timedelta, date
+
 from django.test import TestCase
-from models import GroupStat, GroupStatistic
+from django.utils import timezone
 from vkontakte_groups.factories import GroupFactory
-from datetime import datetime, timedelta
+
+from .models import GroupStat, GroupStatistic
 
 GROUP_ID = 1
 
+
 class VkontakteGroupsStatisticTest(TestCase):
 
     def test_fetch_statistic(self):
@@ -14,23 +18,23 @@ class VkontakteGroupsStatisticTest(TestCase):
         self.assertEqual(GroupStat.objects.count(), 0)
 
         group.fetch_statistic()
-        self.assertTrue(GroupStat.objects.count() > 350)
+        self.assertGreater(GroupStat.objects.count(), 350)
 
         stat = GroupStat.objects.filter(period=30)[0]
-        self.assertTrue(stat.views > 0)
-        self.assertTrue(stat.visitors > 0)
-        self.assertNotEqual(stat.date, None)
+        self.assertGreater(stat.views, 0)
+        self.assertGreater(stat.visitors, 0)
+        self.assertIsInstance(stat.date, date)
 
         stat = GroupStat.objects.filter(period=1)[0]
-        self.assertTrue(stat.members > 0)
-        self.assertTrue(stat.views > 0)
-        self.assertTrue(stat.visitors > 0)
-        self.assertTrue(stat.males > 0)
-        self.assertTrue(stat.females > 0)
-        self.assertNotEqual(stat.date, None)
+        self.assertGreater(stat.members, 0)
+        self.assertGreater(stat.views, 0)
+        self.assertGreater(stat.visitors, 0)
+        self.assertGreater(stat.males, 0)
+        self.assertGreater(stat.females, 0)
+        self.assertIsInstance(stat.date, date)
 
         # test date_from argument
-        date_from = datetime.now() - timedelta(5)
+        date_from = timezone.now() - timedelta(5)
         stat_month_count = GroupStat.objects.filter(period=30).count()
         GroupStat.objects.all().delete()
 
@@ -44,11 +48,11 @@ class VkontakteGroupsStatisticTest(TestCase):
         self.assertEqual(GroupStatistic.objects.count(), 0)
 
         group.fetch_statistic(source='api')
-        self.assertNotEqual(GroupStatistic.objects.count(), 0)
+        self.assertGreater(GroupStatistic.objects.count(), 0)
 
         stat = GroupStatistic.objects.all()[0]
-        self.assertTrue(stat.views > 0)
-        self.assertTrue(stat.visitors > 0)
-        self.assertTrue(stat.males > 0)
-        self.assertTrue(stat.females > 0)
-        self.assertNotEqual(stat.date, None)
\ No newline at end of file
+        self.assertGreater(stat.views, 0)
+        self.assertGreater(stat.visitors, 0)
+        self.assertGreater(stat.males, 0)
+        self.assertGreater(stat.females, 0)
+        self.assertIsInstance(stat.date, date)
